import gym
from gym import error,spaces,utils
from gym.utils import seeding

class NavEnv(gym.Env):
	metadata={'render.modes':['human']}
	
	def __init__(self):
		...
	
	def step(self,action):
		...
	
	def reset(self):
		...
	
	def render(self,mode='human'):
		...
	
	def close(self):
		...



from gym.envs.registration import register

register(
	id='nav_env-v0',
	entry_point='Egistic_Nav_Env.envs:NavEnv',
	)
register(
	id='foo-extrahard-v0',
	entry_point='Egistic_Nav_Env.envs:NavExtraHardEnv',
	)
